/*
 * Copyright (c) 2020 Nordic Semiconductor ASA
 *
 * SPDX-License-Identifier: LicenseRef-BSD-5-Clause-Nordic
 */

#include <sys/printk.h>
#include <drivers/gpio.h>
#include <hal/nrf_gpio.h>


#define PIN_1 6
#define PIN_2 7
#define PIN_3 8


struct k_timer multi_shot_timer;
static struct device *gpio_dev;

static void my_expiry_function(struct k_timer *timer)
{
	ARG_UNUSED(timer);
	
	gpio_pin_toggle(gpio_dev,PIN_1);
	gpio_pin_toggle(gpio_dev,PIN_2);
	gpio_pin_toggle(gpio_dev,PIN_3);

}




void main(void)
{
	printk("Starting GPIO Test example\n");

    int err;

	gpio_dev = device_get_binding(DT_LABEL(DT_NODELABEL(gpio0)));
	if (gpio_dev == NULL) {
		printk("GPIO_0 bind error");
		return;
	}
	
	
	err = gpio_pin_configure(gpio_dev, PIN_1,
				GPIO_OUTPUT | GPIO_OUTPUT_INIT_LOW);	
	if (err) {
		printk("PIN_1 config error: %d", err);
	}
	
	err = gpio_pin_configure(gpio_dev, PIN_2,
				GPIO_OUTPUT | GPIO_OUTPUT_INIT_LOW);	
	if (err) {
		printk("PIN_2 config error: %d", err);
	}
	
	err = gpio_pin_configure(gpio_dev, PIN_3,
				GPIO_OUTPUT | GPIO_OUTPUT_INIT_LOW);	
	if (err) {
		printk("PIN_3 config error: %d", err);
	}
	
	k_timer_start(&multi_shot_timer, K_NO_WAIT, K_MSEC(1000) ); // For older APIs, use 0 instead of K_NO_WAIT
}

K_TIMER_DEFINE(multi_shot_timer,  my_expiry_function, NULL);
